from .RANDFUNC import *

__title__ = "randfunc"
__summary__ = "Randfunc is a collection of random functions."
__uri__ = "https://github.com/Cu3t0m/randfunc"
__version__ = "0.0.3"
__author__ = "Custom"
__email__ = "diwanmohamedfaheer@gmail.com"
__license__ = "MIT License"
__copyright__ = "Copyright 2021 {}".format(__author__)


def get_version():
    return __version__